aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.World/ResultSlot.h
diff options
context:
space:
mode:
Diffstat (limited to 'Minecraft.World/ResultSlot.h')
-rw-r--r--Minecraft.World/ResultSlot.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/Minecraft.World/ResultSlot.h b/Minecraft.World/ResultSlot.h
index 28e464f0..b8308f66 100644
--- a/Minecraft.World/ResultSlot.h
+++ b/Minecraft.World/ResultSlot.h
@@ -5,22 +5,22 @@
class ResultSlot : public Slot
{
private:
- shared_ptr<Container> craftSlots;
- Player *player; // This can't be a shared_ptr, as we create a result slot in the inventorymenu in the Player ctor
+ std::shared_ptr<Container> craftSlots;
+ Player *player; // This can't be a std::shared_ptr, as we create a result slot in the inventorymenu in the Player ctor
int removeCount;
public:
- ResultSlot(Player *player, shared_ptr<Container> craftSlots, shared_ptr<Container> container, int id, int x, int y);
+ ResultSlot(Player *player, std::shared_ptr<Container> craftSlots, std::shared_ptr<Container> container, int id, int x, int y);
virtual ~ResultSlot() {}
- virtual bool mayPlace(shared_ptr<ItemInstance> item);
- virtual shared_ptr<ItemInstance> remove(int c);
+ virtual bool mayPlace(std::shared_ptr<ItemInstance> item);
+ virtual std::shared_ptr<ItemInstance> remove(int c);
protected:
- virtual void onQuickCraft(shared_ptr<ItemInstance> picked, int count);
- virtual void checkTakeAchievements(shared_ptr<ItemInstance> carried);
+ virtual void onQuickCraft(std::shared_ptr<ItemInstance> picked, int count);
+ virtual void checkTakeAchievements(std::shared_ptr<ItemInstance> carried);
public:
- virtual void onTake(shared_ptr<Player> player, shared_ptr<ItemInstance> carried);
- virtual bool mayCombine(shared_ptr<ItemInstance> item); // 4J Added
+ virtual void onTake(std::shared_ptr<Player> player, std::shared_ptr<ItemInstance> carried);
+ virtual bool mayCombine(std::shared_ptr<ItemInstance> item); // 4J Added
}; \ No newline at end of file